<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Information</name>
    <message>
        <location filename="../Information.js" line="+285"/>
        <source>Information Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia informacji</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show information tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia informacji</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Info</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Info</translatorcomment>
        <translation>&amp;Informacja</translation>
    </message>
    <message>
        <location filename="../Information.ui" line="+17"/>
        <source>Add measurement to drawing</source>
        <translation>Dodanie pomiaru do rysunku</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Text height:</source>
        <translation>Wysokość tekstu:</translation>
    </message>
</context>
</TS>
